@@ -4,12 +4,14 @@ test_that("batchMap", {
   reg = makeTestRegistry()
   batchMap(reg, function(x) x^2, 1:3)
   submitJobs(reg)
+  waitForJobs(reg)
   y = sapply(getJobIds(reg), function(id) loadResult(reg, id))
   expect_equal(y, (1:3)^2, check.attributes = FALSE)
 
   reg = makeTestRegistry()
   batchMap(reg, function(x,y,z) (x+y)*z, 1:3, 4:6, more.args=list(z=2))
   submitJobs(reg)
+  waitForJobs(reg)
   y = sapply(getJobIds(reg), function(id) loadResult(reg, id))
   expect_equal(y, ((1:3) + (4:6))*2, check.attributes = FALSE)
 
@@ -26,8 +28,9 @@ test_that("batchMap", {
 #   reg = makeTestRegistry()
 #   ids = batchMap(reg, identity, factor(letters[1:5]))
 #   submitJobs(reg)
+#   waitForJobs(reg)
 #   expect_equal(loadResults(reg, simplify=TRUE), setNames(factor(letters[1:5]), 1:5))
-# 
+#
 #   reg = makeTestRegistry()
 #   ids = batchMap(reg, identity, overloaded.index.obj)
 #   submitJobs(reg)
